import { FC, useState } from "react";
import { OutlinedButton } from "@src/components/common/buttons/outlinedButton";
import { PrimaryButton } from "@src/components/common/buttons/primaryButton";
import { TodoShortForm } from "@src/components/todos/collapsed/todoShortForm";
import { Priorities } from "@src/core/entities/todo";

export const AddTodoForm: FC<{
  onAdd: (
    todoName: string,
    project: string,
    description: string,
    priority?: Priorities
  ) => void;
  onClose: () => void;
  project: string;
  priority?: Priorities;
}> = ({ onAdd, onClose, ...props }) => {
  const [todoName, setTodoName] = useState("");
  const [todoDescription, setTodoDescription] = useState("");
  const [project, setProject] = useState(props.project);
  const [priority, setPriority] = useState(props.priority);

  return (
    <form
      onSubmit={(e) => {
        e.preventDefault();
        onAdd(todoName, project, todoDescription, priority);
        setTodoName("");
        setTodoDescription("");
      }}
    >
      <div className="py-2 space-y-3">
        <TodoShortForm
          project={project}
          onProjectChanged={(p) => setProject(p)}
          priority={priority}
          onPriorityChanged={setPriority}
          name={todoName}
          onNameChange={(e) => setTodoName(e.target.value)}
          description={todoDescription}
          onDescriptionChange={(e) => setTodoDescription(e.target.value)}
        />
        <div className="space-x-2">
          <PrimaryButton disabled={!todoName} type="submit">
            Add todo
          </PrimaryButton>
          <OutlinedButton onClick={onClose}>Cancel</OutlinedButton>
        </div>
      </div>
    </form>
  );
};
